@@ -47,7 +47,7 @@ def main():
         help='output file or directory (if it ends with .json it is '
              'recognized as file, else as directory)'
     )
-    default_config_file = os.path.join(os.path.expanduser('~'), 'labelme+config')
+    default_config_file = os.path.join(os.path.expanduser('~'), 'lconfig')
     parser.add_argument(
         '--config',
         dest='config',
@@ -174,7 +174,7 @@ def main():
     if not config['labels'] and config['validate_label']:
         logger.error('--labels must be specified with --validatelabel or '
                      'validate_label: true in the config file '
-                     '(ex. ~/labelme+config).')
+                     '(ex. ~/lconfig).')
         sys.exit(1)
 
     output_file = None
