@@ -51,10 +51,6 @@ from enhancedlabelme.widgets import ZoomWidget
 LABEL_COLORMAP = imgviz.label_colormap(value=200)
 os.environ['QT_API'] = 'pyqt5'
 
-class th:
-    def __init__(self):
-        self.a=3
-
 class MainWindow(QtWidgets.QMainWindow):
 
     FIT_WINDOW, FIT_WIDTH, MANUAL_ZOOM = 0, 1, 2
@@ -144,6 +140,9 @@ class MainWindow(QtWidgets.QMainWindow):
         self.label_dock.setWidget(self.uniqLabelList)
 
         self.fileSearch = QtWidgets.QLineEdit()
+        # try:
+        #     self.fileSearch.setPlaceholderText(self.tr(self.filename))
+        # except Exception:
         self.fileSearch.setPlaceholderText(self.tr('Search Filename'))
         self.fileSearch.textChanged.connect(self.fileSearchChanged)
         self.fileListWidget = QtWidgets.QListWidget()
@@ -433,12 +432,12 @@ class MainWindow(QtWidgets.QMainWindow):
             "Adjust brightness and contrast",
             enabled=False,
         )
-        crossHair = action(self.tr('&Toggle cross hair(+)'), self.crossHairToggle,
-                           shortcuts['cross_hair'], 'cross_hair',
+        crossHair = action(self.tr('&Show Cross-line'), self.crossHairToggle,
+                           shortcuts['cross_hair'], icon='cross',
                            tip=self.tr('Show cross hair around the mouse cursor'),
                            checkable=True, checked=self._config['cross_hair'],)
         crossHair.setChecked(self._config['cross_hair'])
-        darkMode = action(self.tr('&Toggle dark theme'), self.darkModeToggle,
+        darkMode = action(self.tr('&Dark Theme'), self.darkModeToggle, icon='dark',
                 tip=self.tr('Toggle dark theme'), checkable=True, checked=self._config['dark_mode'],)
 
         # Group zoom controls into a list for easier toggling.
@@ -561,7 +560,7 @@ class MainWindow(QtWidgets.QMainWindow):
             view=self.menu(self.tr('&View')),
             help=self.menu(self.tr('&Help')),
             recentFiles=QtWidgets.QMenu(self.tr('Open &Recent File')),
-            recentDirectories=QtWidgets.QMenu(self.tr('Open &Recent Directory')),
+            #recentDirectories=QtWidgets.QMenu(self.tr('Open &Recent Directory')),
             labelList=labelMenu,
         )
 
@@ -573,7 +572,7 @@ class MainWindow(QtWidgets.QMainWindow):
                 openPrevImg,
                 opendir,
                 self.menus.recentFiles,
-                self.menus.recentDirectories,
+                #self.menus.recentDirectories,
                 save,
                 saveAs,
                 saveAuto,
@@ -615,9 +614,7 @@ class MainWindow(QtWidgets.QMainWindow):
                 darkMode,
             ),
         )
-
         self.menus.file.aboutToShow.connect(self.updateFileMenu)
-        #self.menus.file.aboutToShow.connect(self.updateDirectoryMenu)
 
         # Custom context menu for the canvas widget:
         utils.addActions(self.canvas.menus[0], self.actions.menu)
@@ -666,7 +663,7 @@ class MainWindow(QtWidgets.QMainWindow):
         self.image = QtGui.QImage()
         self.imagePath = None
         self.recentFiles = []
-        self.recentDirectories = []
+        #self.recentDirectories = []
         self.maxRecent = 10
         self.otherData = None
         self.zoom_level = 100
@@ -692,7 +689,7 @@ class MainWindow(QtWidgets.QMainWindow):
         self.settings = QtCore.QSettings('enhancedlabelme', 'enhancedlabelme')
         # FIXME: QSettings.value can return None on PyQt4
         self.recentFiles = self.settings.value('recentFiles', []) or []
-        self.recentDirectories = self.settings.value('recentDirectories', []) or []
+        #self.recentDirectories = self.settings.value('recentDirectories', []) or []
         size = self.settings.value('window/size', QtCore.QSize(600, 500))
         position = self.settings.value('window/position', QtCore.QPoint(0, 0))
         self.resize(size)
@@ -704,7 +701,7 @@ class MainWindow(QtWidgets.QMainWindow):
 
         # Populate the File menu dynamically.
         self.updateFileMenu()
-        self.updateDirectoryMenu()
+        #self.updateDirectoryMenu()
         # Since loading the file may take some time,
         # make sure it runs in the background.
         if self.filename is not None:
@@ -835,12 +832,12 @@ class MainWindow(QtWidgets.QMainWindow):
             self.recentFiles.pop()
         self.recentFiles.insert(0, filename)
         
-    def addRecentDirectory(self, dirpath):
-        if dirpath in self.recentDirectories:
-            self.recentDirectories.remove(dirpath)
-        elif len(self.recentDirectories) >= self.maxRecent:
-            self.recentDirectories.pop()
-        self.recentDirectories.insert(0, dirpath)
+    # def addRecentDirectory(self, dirpath):
+    #     if dirpath in self.recentDirectories:
+    #         self.recentDirectories.remove(dirpath)
+    #     elif len(self.recentDirectories) >= self.maxRecent:
+    #         self.recentDirectories.pop()
+    #     self.recentDirectories.insert(0, dirpath)
 
     # Callbacks
 
@@ -851,12 +848,15 @@ class MainWindow(QtWidgets.QMainWindow):
         self.actions.undo.setEnabled(self.canvas.isShapeRestorable)
         
     def preference(self):
-        if platform.system() == 'Darwin':       # macOS
-            subprocess.call(('open', os.path.join(os.path.expanduser('~'), 'labelme+config')))
-        elif platform.system() == 'Windows':    # Windows
-            subprocess.call(('notepad.exe', os.path.join(os.path.expanduser('~'), 'labelme+config')))
-        else:                                   # linux variants
-            subprocess.call(('xdg-open', os.path.join(os.path.expanduser('~'), 'labelme+config')))
+        try:
+            if platform.system() == 'Darwin':       # macOS
+                subprocess.call(('open', os.path.join(os.path.expanduser('~'), 'lconfig')))
+            elif platform.system() == 'Windows':    # Windows
+                subprocess.call(('notepad.exe', os.path.join(os.path.expanduser('~'), 'lconfig')))
+            else:                                   # linux variants
+                subprocess.call(('xdg-open', os.path.join(os.path.expanduser('~'), 'lconfig')))
+        except Exception:
+            pass
 
     def about(self):
         return QtWidgets.QMessageBox.about(
@@ -972,24 +972,24 @@ class MainWindow(QtWidgets.QMainWindow):
             action.triggered.connect(functools.partial(self.loadRecent, f))
             menu.addAction(action)
             
-    def updateDirectoryMenu(self):
-        try:
-            current = osp.dirname(self.filename)
+    # def updateDirectoryMenu(self):
+    #     try:
+    #         current = osp.dirname(self.filename)
 
-            def exists(filename):
-                return osp.exists(str(filename))
+    #         def exists(filename):
+    #             return osp.exists(str(filename))
 
-            menu = self.menus.recentDirectories
-            menu.clear()
-            directories = [f for f in self.recentDirectories if f != current and exists(f)]
-            for i, f in enumerate(directories):
-                icon = utils.newIcon('labels')
-                action = QtWidgets.QAction(
-                    icon, '&%d %s' % (i + 1, current), self)
-                action.triggered.connect(functools.partial(self.loadRecentDirectory, f))
-                menu.addAction(action)
-        except Exception:
-            pass
+    #         menu = self.menus.recentDirectories
+    #         menu.clear()
+    #         directories = [f for f in self.recentDirectories if f != current and exists(f)]
+    #         for i, f in enumerate(directories):
+    #             icon = utils.newIcon('labels')
+    #             action = QtWidgets.QAction(
+    #                 icon, '&%d %s' % (i + 1, current), self)
+    #             action.triggered.connect(functools.partial(self.loadRecentDirectory, f))
+    #             menu.addAction(action)
+    #     except Exception:
+    #         pass
 
     def popLabelListMenu(self, point):
         self.menus.labelList.exec_(self.labelList.mapToGlobal(point))
@@ -1585,7 +1585,7 @@ class MainWindow(QtWidgets.QMainWindow):
         self.settings.setValue('window/position', self.pos())
         self.settings.setValue('window/state', self.saveState())
         self.settings.setValue('recentFiles', self.recentFiles)
-        self.settings.setValue('recentDirectories', self.recentDirectories)
+        #self.settings.setValue('recentDirectories', self.recentDirectories)
         # ask the use for where to save the labels
         # self.settings.setValue('window/geometry', self.saveGeometry())
         
@@ -1613,10 +1613,6 @@ class MainWindow(QtWidgets.QMainWindow):
     def loadRecent(self, filename):
         if self.mayContinue():
             self.loadFile(filename)
-            
-    def loadRecentDirectory(self,dirpath):
-        if self.mayContinue():
-            self.loadDir(dirpath)
 
     def openPrevImg(self, _value=False):
         keep_prev = self._config['keep_prev']
@@ -1891,27 +1887,27 @@ class MainWindow(QtWidgets.QMainWindow):
         if not self.mayContinue():
             return
 
-        defaultOpenDirPath = dirpath if dirpath else '.'
-        if self.lastOpenDir and osp.exists(self.lastOpenDir):
-            defaultOpenDirPath = self.lastOpenDir
-        else:
-            defaultOpenDirPath = osp.dirname(self.filename) \
-                if self.filename else '.'
+        try:
+            defaultOpenDirPath = dirpath if dirpath else "."
+            if self.lastOpenDir and osp.exists(self.lastOpenDir):
+                defaultOpenDirPath = self.lastOpenDir
+            else:
+                defaultOpenDirPath = (
+                    osp.dirname(self.filename) if self.filename else "."
+                )
 
-        targetDirPath = str(QtWidgets.QFileDialog.getExistingDirectory(
-            self,
-            self.tr('%s - Open Directory') % __appname__,
-            defaultOpenDirPath,
-            QtWidgets.QFileDialog.ShowDirsOnly |
-            QtWidgets.QFileDialog.DontResolveSymlinks))
-        self.importDirImages(targetDirPath)
-        
-    def loadDir(self, dirpath):
-        if not self.mayContinue():
-            return
-        self.addRecentDirectory(dirpath)
-        self.importDirImages(dirpath)
-       
+            targetDirPath = str(
+                QtWidgets.QFileDialog.getExistingDirectory(
+                    self,
+                    self.tr("%s - Open Directory") % __appname__,
+                    defaultOpenDirPath,
+                    QtWidgets.QFileDialog.ShowDirsOnly
+                    | QtWidgets.QFileDialog.DontResolveSymlinks,
+                )
+            )
+            self.importDirImages(targetDirPath)
+        except:
+            pass
 
     @property
     def imageList(self):
