@@ -84,7 +84,6 @@ class Canvas(QtWidgets.QWidget):
         # Set widget options.
         self.setMouseTracking(True)
         self.setFocusPolicy(QtCore.Qt.WheelFocus)
-        self.eventc = None
         self.cross = False
         self.posc = None
 
@@ -521,55 +520,57 @@ class Canvas(QtWidgets.QWidget):
             self.boundedMoveShapes(shapes, point + offset)
 
     def paintEvent(self, event):
-        if not self.pixmap:
-            return super(Canvas, self).paintEvent(event)
-        self.eventc = event
-        p = self._painter       
-        p.begin(self)
-        p.setRenderHint(QtGui.QPainter.Antialiasing)
-        p.setRenderHint(QtGui.QPainter.HighQualityAntialiasing)
-        p.setRenderHint(QtGui.QPainter.SmoothPixmapTransform)
-
-        p.scale(self.scale, self.scale)
-        p.translate(self.offsetToCenter())
-        
-        p.drawPixmap(0, 0, self.pixmap)
-        Shape.scale = self.scale
-        
-        if self.cross_onoff == True and self.cross_temp == 0:
-            self.cross_temp = 1
-            self.cross = True
         try:
-            if self.cross == True:
-                p.setPen(QtGui.QPen(QtCore.Qt.black, 0.7, QtCore.Qt.SolidLine))
-                p.drawLine(self.posc.x(), self.pixmap.height(), self.posc.x(), 0)
-                p.drawLine(0, self.posc.y(), self.pixmap.width(), self.posc.y())
-                self.update()
+            if not self.pixmap:
+                return super(Canvas, self).paintEvent(event)
+            p = self._painter       
+            p.begin(self)
+            p.setRenderHint(QtGui.QPainter.Antialiasing)
+            p.setRenderHint(QtGui.QPainter.HighQualityAntialiasing)
+            p.setRenderHint(QtGui.QPainter.SmoothPixmapTransform)
+
+            p.scale(self.scale, self.scale)
+            p.translate(self.offsetToCenter())
+            
+            p.drawPixmap(0, 0, self.pixmap)
+            Shape.scale = self.scale
+            
+            if self.cross_onoff == True and self.cross_temp == 0:
+                self.cross_temp = 1
+                self.cross = True
+            try:
+                if self.cross == True and self.pixmap:
+                    p.setPen(QtGui.QPen(QtCore.Qt.black, 0.9, QtCore.Qt.DashLine))
+                    p.drawLine(self.posc.x(), self.pixmap.height(), self.posc.x(), 0)
+                    p.drawLine(0, self.posc.y(), self.pixmap.width(), self.posc.y())
+                    self.update()
+            except Exception:
+                pass
+
+            for shape in self.shapes:
+                if (shape.selected or not self._hideBackround) and \
+                        self.isVisible(shape):
+                    shape.fill = shape.selected or shape == self.hShape
+                    shape.paint(p)
+            if self.current:
+                self.current.paint(p)
+                self.line.paint(p)
+            if self.selectedShapesCopy:
+                for s in self.selectedShapesCopy:
+                    s.paint(p)
+
+            if (self.fillDrawing() and self.createMode == 'polygon' and
+                    self.current is not None and len(self.current.points) >= 2):
+                drawing_shape = self.current.copy()
+                drawing_shape.addPoint(self.line[1])
+                drawing_shape.fill = True
+                drawing_shape.fill_color.setAlpha(64)
+                drawing_shape.paint(p)
+
+            p.end()
         except Exception:
             pass
 
-        for shape in self.shapes:
-            if (shape.selected or not self._hideBackround) and \
-                    self.isVisible(shape):
-                shape.fill = shape.selected or shape == self.hShape
-                shape.paint(p)
-        if self.current:
-            self.current.paint(p)
-            self.line.paint(p)
-        if self.selectedShapesCopy:
-            for s in self.selectedShapesCopy:
-                s.paint(p)
-
-        if (self.fillDrawing() and self.createMode == 'polygon' and
-                self.current is not None and len(self.current.points) >= 2):
-            drawing_shape = self.current.copy()
-            drawing_shape.addPoint(self.line[1])
-            drawing_shape.fill = True
-            drawing_shape.fill_color.setAlpha(64)
-            drawing_shape.paint(p)
-
-        p.end()
-
     def transformPos(self, point):
         """Convert from widget-logical coordinates to painter-logical ones."""
         return point / self.scale - self.offsetToCenter()
